'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsCore = require('@lorisleiva/js-core');
var jsWeb3jsAdapters = require('@lorisleiva/js-web3js-adapters');
var web3_js = require('@solana/web3.js');
var bs58 = require('bs58');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var bs58__default = /*#__PURE__*/_interopDefaultLegacy(bs58);

class Web3JsRpc {
  constructor(context, endpoint, rpcOptions) {
    this.context = context;
    this.connection = new web3_js.Connection(endpoint, rpcOptions);
    this.cluster = jsCore.resolveClusterFromEndpoint(endpoint);
  }
  getEndpoint() {
    return this.connection.rpcEndpoint;
  }
  getCluster() {
    return this.cluster;
  }
  async getAccount(address) {
    const account = await this.connection.getAccountInfo(jsWeb3jsAdapters.toWeb3JsPublicKey(address));
    return this.parseMaybeAccount(account, address);
  }
  async call(method, params, options = {}) {
    const client = this.connection._rpcClient;
    return new Promise((resolve, reject) => {
      const callback = (error, result) => error ? reject(error) : resolve(result);
      client.request(method, params, options.id ?? null, callback);
    });
  }
  async sendTransaction(serializedTransaction, options) {
    try {
      const signature = await this.connection.sendRawTransaction(serializedTransaction, options);
      return bs58__default["default"].decode(signature);
    } catch (error) {
      let resolvedError = null;
      if (error instanceof Error && 'logs' in error) {
        resolvedError = this.context.programs.resolveError(error);
      }
      throw resolvedError || error;
    }
  }
  async confirmTransaction(signature, blockhashWithExpiryBlockHeight, commitment) {
    return this.connection.confirmTransaction({
      signature: bs58__default["default"].encode(signature),
      ...blockhashWithExpiryBlockHeight
    }, commitment);
  }
  parseMaybeAccount(account, address) {
    return account ? {
      ...account,
      owner: jsWeb3jsAdapters.fromWeb3JsPublicKey(account.owner),
      exists: true,
      address,
      lamports: jsCore.lamports(account.lamports)
    } : {
      exists: false,
      address
    };
  }
}

exports.Web3JsRpc = Web3JsRpc;
//# sourceMappingURL=Web3JsRpc.cjs.map
