import { BlockhashWithExpiryBlockHeight, Cluster, Commitment, Context, MaybeRpcAccount, PublicKey, RpcConfirmResult, RpcInterface, RpcOptions, RpcSendOptions, SerializedTransaction, TransactionSignature } from '@lorisleiva/js-core';
import { AccountInfo as Web3JSAccountInfo, Connection as Web3JsConnection, ConnectionConfig as Web3JsConnectionConfig } from '@solana/web3.js';
export type Web3JsRpcOptions = Commitment | Web3JsConnectionConfig;
export declare class Web3JsRpc implements RpcInterface {
    protected readonly context: Pick<Context, 'programs'>;
    readonly connection: Web3JsConnection;
    readonly cluster: Cluster;
    constructor(context: Pick<Context, 'programs'>, endpoint: string, rpcOptions?: Web3JsRpcOptions);
    getEndpoint(): string;
    getCluster(): Cluster;
    getAccount(address: PublicKey): Promise<MaybeRpcAccount>;
    call<Result, Params extends any[]>(method: string, params?: [...Params], options?: RpcOptions): Promise<Result>;
    sendTransaction(serializedTransaction: SerializedTransaction, options?: RpcSendOptions): Promise<TransactionSignature>;
    confirmTransaction(signature: TransactionSignature, blockhashWithExpiryBlockHeight: BlockhashWithExpiryBlockHeight, commitment?: Commitment): Promise<RpcConfirmResult>;
    protected parseMaybeAccount(account: Web3JSAccountInfo<Uint8Array> | null, address: PublicKey): MaybeRpcAccount;
}
